@@ -232,6 +232,9 @@ async def sync_classes():
             ),
         )
     except Exception as e:
+        print_flush(
+                "Exception trying to send message back to container for sync_classes! " + str(sys.exc_info()[-1].tb_lineno) + " " + str(e)
+            )
         await send_status(
             message='{"message": "Error while syncing info: {}"}'.format(
                 str(traceback.format_exc())
